@@ -1,7 +1,8 @@
 # binaries -- lintian check script -*- perl -*-
 
-# Copyright (C) 1998 Christian Schwarz and Richard Braakman
-# Copyright (C) 2012 Kees Cook
+# Copyright © 1998 Christian Schwarz and Richard Braakman
+# Copyright © 2012 Kees Cook
+# Copyright © 2017-2020 Chris Lamb <lamby@debian.org>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -21,8 +22,9 @@
 
 package Lintian::binaries;
 
-use strict;
+use v5.20;
 use warnings;
+use utf8;
 use autodie;
 
 use File::Spec;
@@ -31,7 +33,6 @@ use List::MoreUtils qw(any);
 use Lintian::Data;
 use Lintian::Relation qw(:constants);
 use Lintian::Spelling qw(check_spelling);
-use Lintian::Util qw(strip);
 
 use constant NUMPY_REGEX => qr/
     \Qmodule compiled against ABI version \E (?:0x)?%x
@@ -80,7 +81,10 @@ sub _embedded_libs {
         $regex = $opts;
         $opts = '';
     } else {
-        strip($opts);
+
+        # trim both ends
+        $opts =~ s/^\s+|\s+$//g;
+
         foreach my $optstr (split m/\s++/, $opts) {
             my ($opt, $val) = split m/=/, $optstr, 2;
             if ($opt eq 'source' or $opt eq 'libname') {
@@ -463,8 +467,8 @@ sub installable {
             # stripped but a debug or profiling library?
             if (($fname =~ m,/lib/debug/,o) or ($fname =~ m,/lib/profile/,o)){
                 $self->tag(
-                    'library-in-debug-or-profile-should-not-be-stripped',
-                    $file);
+                    'library-in-debug-or-profile-should-not-be-stripped',$file)
+                  unless $file->size == 0;
             } else {
                 # appropriately stripped, but is it stripped enough?
                 $self->tag_unneeded_sections('binary-has-unneeded-section',
@@ -721,8 +725,8 @@ sub installable {
         }
     }
 
-    # Check for dependency on python-numpy-abiN dependency (or strict versioned
-    # dependency on python-numpy)
+    # Check for dependency on python3-numpy-abiN dependency (or strict
+    # versioned dependency on python3-numpy)
     if ($uses_numpy_c_abi and $pkg !~ m{\A python3?-numpy \Z}xsm) {
         # We do not allow alternatives as it would mostly likely
         # defeat the purpose of this relation.  Also, we do not allow
@@ -730,8 +734,8 @@ sub installable {
         my $vflags = VISIT_OR_CLAUSE_FULL;
         $self->tag('missing-dependency-on-numpy-abi')
           unless $depends->matches(qr/^python3?-numpy-abi\d+$/, $vflags)
-          or (  $depends->matches(qr/^python-numpy \(>[>=][^\|]+$/, $vflags)
-            and $depends->matches(qr/^python-numpy \(<[<=][^\|]+$/, $vflags));
+          or (  $depends->matches(qr/^python3-numpy \(>[>=][^\|]+$/, $vflags)
+            and $depends->matches(qr/^python3-numpy \(<[<=][^\|]+$/, $vflags));
     }
 
     return;
