@@ -1,6 +1,7 @@
 # debhelper format -- lintian check script -*- perl -*-
 
-# Copyright (C) 1999 by Joey Hess
+# Copyright © 1999 by Joey Hess
+# Copyright © 2016-2020 Chris Lamb <lamby@debian.org>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,8 +21,9 @@
 
 package Lintian::debhelper;
 
-use strict;
+use v5.20;
 use warnings;
+use utf8;
 use autodie;
 
 use List::MoreUtils qw(any);
@@ -29,7 +31,6 @@ use Text::Levenshtein qw(distance);
 
 use Lintian::Data;
 use Lintian::Relation qw(:constants);
-use Lintian::Util qw(strip);
 
 use Moo;
 use namespace::clean;
@@ -75,6 +76,7 @@ sub source {
     $bdepends = $processable->relation('build-depends-all');
     my $seen_dh = 0;
     my $seen_dh_dynamic = 0;
+    my $seen_dh_systemd = 0;
     my $seen_dh_parallel = 0;
     my %seen = (
         'python2' => 0,
@@ -176,6 +178,7 @@ sub source {
                         );
                         $uses_autotools_dev_dh = 1;
                     }
+                    $seen_dh_systemd = $. if $addon eq 'systemd';
                     $self->tag(
                         'dh-quilt-addon-but-quilt-source-format',
                         "dh ... --with ${orig_addon}",
@@ -210,6 +213,9 @@ sub source {
             $dhcompatvalue = $1;
             # one can export and then set the value:
             $level = $1 if ($level);
+        } elsif (/^[^:]*override\s+(dh_[^:]*):/) {
+            $self->tag('typo-in-debhelper-override-target',
+                "override $1", '->', "override_$1","(line $.)");
         } elsif (/^([^:]*override_dh_[^:]*):/) {
             my $targets = $1;
             $needbuilddepends = 1;
@@ -333,7 +339,11 @@ sub source {
         open(my $fd, '<', $compat_file->unpacked_path);
         while (<$fd>) {
             if ($. == 1) {
-                $compat = strip($_);
+                $compat = $_;
+
+                # trim both ends
+                $compat =~ s/^\s+|\s+$//g;
+
             } elsif (m/^\d/) {
                 $self->tag('debhelper-compat-file-contains-multiple-levels',
                     "(line $.)");
@@ -412,6 +422,11 @@ sub source {
         "(line $seen_dh_parallel)"
     ) if $seen_dh_parallel and $level >= 10;
 
+    $self->tag(
+        'debian-rules-uses-unnecessary-dh-argument',
+        "dh ... --with=systemd (line $seen_dh_systemd)"
+    ) if $seen_dh_systemd and $level >= 10;
+
     # Check the files in the debian directory for various debhelper-related
     # things.
     for my $file ($droot->children) {
@@ -713,7 +728,8 @@ sub _shebang_cmd {
             # correctly.
             $cmd = '' if $cmd =~ m/^#!/o;
 
-            strip($cmd);
+            # trim both ends
+            $cmd =~ s/^\s+|\s+$//g;
         }
     }
     close($fd);
