@@ -1,9 +1,9 @@
 # fields/package -- lintian check script (rewrite) -*- perl -*-
 #
-# Copyright (C) 2004 Marc Brockschmidt
+# Copyright © 2004 Marc Brockschmidt
 #
 # Parts of the code were taken from the old check script, which
-# was Copyright (C) 1998 Richard Braakman (also licensed under the
+# was Copyright © 1998 Richard Braakman (also licensed under the
 # GPL 2 or higher)
 #
 # This program is free software; you can redistribute it and/or modify
@@ -24,8 +24,9 @@
 
 package Lintian::fields::package;
 
-use strict;
+use v5.20;
 use warnings;
+use utf8;
 use autodie;
 
 use Lintian::Util qw($PKGNAME_REGEX);
@@ -35,7 +36,7 @@ use namespace::clean;
 
 with 'Lintian::Check';
 
-sub binary {
+sub installable {
     my ($self) = @_;
 
     my $processable = $self->processable;
