@@ -1,6 +1,7 @@
 # init.d -- lintian check script -*- perl -*-
 
-# Copyright (C) 1998 Christian Schwarz
+# Copyright © 1998 Christian Schwarz
+# Copyright © 2016-2020 Chris Lamb <lamby@debian.org>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,8 +21,9 @@
 
 package Lintian::init_d;
 
-use strict;
+use v5.20;
 use warnings;
+use utf8;
 use autodie;
 
 use File::Basename qw(dirname);
@@ -81,7 +83,10 @@ my $OPTS_R = qr/-\S+\s*/;
 my $ACTION_R = qr/\w+/;
 my $EXCLUDE_R = qr/if\s+\[\s+-x\s+\S*update-rc\.d/;
 
-sub binary {
+my $ALWAYS_START
+  = qr/^\s*#*\s*(?:[A-Z]_)?(?:ENABLED|DISABLED|[A-Z]*RUN|(?:NO_)?START)=/;
+
+sub installable {
     my ($self) = @_;
 
     my $pkg = $self->package;
@@ -101,7 +106,7 @@ sub binary {
 
     # read postinst control file
     if ($postinst and $postinst->is_file and $postinst->is_open_ok) {
-        my $fd = $postinst->open;
+        open(my $fd, '<', $postinst->unpacked_path);
         while (<$fd>) {
             next if /$EXCLUDE_R/o;
             s/\#.*$//o;
@@ -123,7 +128,7 @@ sub binary {
 
     # read preinst control file
     if ($preinst and $preinst->is_file and $preinst->is_open_ok) {
-        my $fd = $preinst->open;
+        open(my $fd, '<', $preinst->unpacked_path);
         while (<$fd>) {
             next if /$EXCLUDE_R/o;
             s/\#.*$//o;
@@ -139,7 +144,7 @@ sub binary {
 
     # read postrm control file
     if ($postrm and $postrm->is_file and $postrm->is_open_ok) {
-        my $fd = $postrm->open;
+        open(my $fd, '<', $postrm->unpacked_path);
         while (<$fd>) {
             next if /$EXCLUDE_R/o;
             s/\#.*$//o;
@@ -158,7 +163,7 @@ sub binary {
 
     # read prerm control file
     if ($prerm and $prerm->is_file and $prerm->is_open_ok) {
-        my $fd = $prerm->open;
+        open(my $fd, '<', $prerm->unpacked_path);
         while (<$fd>) {
             next if /$EXCLUDE_R/o;
             s/\#.*$//o;
@@ -265,7 +270,7 @@ sub check_init {
     my (%tag, %lsb);
     my $in_file_test = 0;
     my $needs_fs = 0;
-    my $fd = $initd_path->open;
+    open(my $fd, '<', $initd_path->unpacked_path);
     while (my $l = <$fd>) {
         if ($. == 1) {
             if ($l
@@ -526,11 +531,11 @@ sub check_defaults {
     return unless $dir and $dir->is_dir;
     for my $path ($dir->children) {
         return if not $path->is_open_ok;
-        my $fd = $path->open;
+        open(my $fd, '<', $path->unpacked_path);
         while (<$fd>) {
             $self->tag('init.d-script-should-always-start-service',
                 $path, "(line $.)")
-              if m/^\s*#*\s*(?:ENABLED|DISABLED|[A-Z]*RUN)=/;
+              if m/$ALWAYS_START/;
         }
         close($fd);
     }
